==> iipimage_1.0.orig.tar.bz2: iipsrv-1.0/doc/html/classView.js <==
var classView =
[
    [ "View", "classView.html#a44ad60a768422d3fa8fbd7576950080a", null ],
    [ "floatProcessing", "classView.html#ae0a2fd77c94dd0c6e9a1698df98eecd6", null ],
    [ "getContrast", "classView.html#a62747ac749a32abbb44a9bf9e8d44715", null ],
    [ "getGamma", "classView.html#a096c7b53865cdeed2fcd74311107f693", null ],
    [ "getImageHeight", "classView.html#aaafd128b63bf2980755b0e0a72bcf2f3", null ],
    [ "getImageWidth", "classView.html#ab9adf6e09e14cd2f13369cf90d3159ad", null ],
    [ "getLayers", "classView.html#aada3d9afaf60efccf67eae06509dc1ed", null ],
    [ "getMaxSize", "classView.html#a77101965d8b2943fb5ca6425823ffa91", null ],
    [ "getRequestHeight", "classView.html#a87e07b51f39c15b94a41decae5c68e91", null ],
    [ "getRequestWidth", "classView.html#a6b373f00ca8790738c20ea85cc07b175", null ],
    [ "getResolution", "classView.html#a28c44d84320f6ad10da70bafa211d558", null ],
    [ "getRotation", "classView.html#a5dd05a3f8dfb297a6ea3931d450348ec", null ],
    [ "getScale", "classView.html#a35752087943e6b754405ec7c95a02963", null ],
    [ "getViewHeight", "classView.html#af6c40d3b25d54873cac0217fb1f33e08", null ],
    [ "getViewLeft", "classView.html#a38d3581c0e6407d921dea25716dc4fd9", null ],
    [ "getViewTop", "classView.html#a25b6deb35d090a5d9be70532256643c1", null ],
    [ "getViewWidth", "classView.html#a183dd9de7291c8cf8d07a380b09d046b", null ],
    [ "setContrast", "classView.html#a823dbdcd4f12f0694c6b2f5111c5e9e0", null ],
    [ "setGamma", "classView.html#a110b8ee780a8609d9d7d8161ef635995", null ],
    [ "setImageSize", "classView.html#ac8709157ac54e0c4cba12ffce1c5aabe", null ],
    [ "setLayers", "classView.html#af6e72554b02976d98058170b3685a371", null ],
    [ "setMaxLayers", "classView.html#ad78accfff9a117df08c02d6061a60157", null ],
    [ "setMaxResolutions", "classView.html#aabd224b6dbb3dc642dc5f6ea73bb2d67", null ],
    [ "setMaxSize", "classView.html#aa8456bd84f6f12ba59fcf61fb575095a", null ],
    [ "setRequestHeight", "classView.html#aefd2a49c9f07977af83d5ff3a8e4586f", null ],
    [ "setRequestWidth", "classView.html#a7f83224c343d82872399bbe6e8b45760", null ],
    [ "setRotation", "classView.html#ae72c9399f734d324ec7804dfd4bef405", null ],
    [ "setViewHeight", "classView.html#acbd157d490921f1945d81f198a8f016f", null ],
    [ "setViewLeft", "classView.html#ae2e0eb95cf0a27d004f4bd13ffda80ad", null ],
    [ "setViewTop", "classView.html#a2bc5a28c964210ea39d1eb270c30200c", null ],
    [ "setViewWidth", "classView.html#a3daf26babf3e0502696d1af401b08232", null ],
    [ "viewPortSet", "classView.html#a0eec96d2a3ec25abba83d639737111be", null ],
    [ "cmap", "classView.html#aef2cc576c53dc89c1b0e56f898637bb0", null ],
    [ "cmapped", "classView.html#ab8f56e796bef6f4f53a2e4b0b96b27e5", null ],
    [ "colourspace", "classView.html#ae4d962c68d2c740d5b74784420624b5c", null ],
    [ "ctw", "classView.html#afa69db05c497c874f872249f6bd24223", null ],
    [ "flip", "classView.html#a5445431e62f1f4fa2b8e39e5b116dd9f", null ],
    [ "inverted", "classView.html#af40f237efd940ec20457da749f8b464e", null ],
    [ "layers", "classView.html#ac2d157433d47b53439fec339fc6be28e", null ],
    [ "maintain_aspect", "classView.html#a5ac9e196f50d7dff4d4dab53f224d748", null ],
    [ "max_layers", "classView.html#a65d44ca93e3e4712909232ab5961e410", null ],
    [ "shade", "classView.html#a6caf330847d42fc8f5527359cade610c", null ],
    [ "shaded", "classView.html#a605b9d2c55831e9daa9d270d17f45c7d", null ],
    [ "xangle", "classView.html#a82a11c648c77bb3a67773fd5449f5bda", null ],
    [ "yangle", "classView.html#a272483c42cab8c6340ccd9aee4a0a590", null ]
];

==> iipimage_1.1.orig.tar.bz2: iipsrv-1.1/doc/html/classView.js <==
var classView =
[
    [ "View", "classView.html#a44ad60a768422d3fa8fbd7576950080a", null ],
    [ "allowUpscaling", "classView.html#ad732826f6c55d0ce153d0f482c985556", null ],
    [ "embedICC", "classView.html#a301581638d9e9866539737b499eafcf0", null ],
    [ "floatProcessing", "classView.html#ae0a2fd77c94dd0c6e9a1698df98eecd6", null ],
    [ "getImageHeight", "classView.html#aaafd128b63bf2980755b0e0a72bcf2f3", null ],
    [ "getImageWidth", "classView.html#ab9adf6e09e14cd2f13369cf90d3159ad", null ],
    [ "getLayers", "classView.html#aada3d9afaf60efccf67eae06509dc1ed", null ],
    [ "getMaxSize", "classView.html#a77101965d8b2943fb5ca6425823ffa91", null ],
    [ "getRequestHeight", "classView.html#a87e07b51f39c15b94a41decae5c68e91", null ],
    [ "getRequestWidth", "classView.html#a6b373f00ca8790738c20ea85cc07b175", null ],
    [ "getResolution", "classView.html#a28c44d84320f6ad10da70bafa211d558", null ],
    [ "getRotation", "classView.html#a5dd05a3f8dfb297a6ea3931d450348ec", null ],
    [ "getScale", "classView.html#a35752087943e6b754405ec7c95a02963", null ],
    [ "getViewHeight", "classView.html#af6c40d3b25d54873cac0217fb1f33e08", null ],
    [ "getViewLeft", "classView.html#a38d3581c0e6407d921dea25716dc4fd9", null ],
    [ "getViewTop", "classView.html#a25b6deb35d090a5d9be70532256643c1", null ],
    [ "getViewWidth", "classView.html#a183dd9de7291c8cf8d07a380b09d046b", null ],
    [ "requireHistogram", "classView.html#a4f3c96d206d264d16d337a10703c85af", null ],
    [ "setAllowUpscaling", "classView.html#ae03ba688fc76fb0c43e3beff937e14aa", null ],
    [ "setEmbedICC", "classView.html#a91fd93084a17cca1b4211ff86d0caa34", null ],
    [ "setImageSize", "classView.html#ac8709157ac54e0c4cba12ffce1c5aabe", null ],
    [ "setLayers", "classView.html#af6e72554b02976d98058170b3685a371", null ],
    [ "setMaxLayers", "classView.html#ad78accfff9a117df08c02d6061a60157", null ],
    [ "setMaxResolutions", "classView.html#aabd224b6dbb3dc642dc5f6ea73bb2d67", null ],
    [ "setMaxSize", "classView.html#aa8456bd84f6f12ba59fcf61fb575095a", null ],
    [ "setRequestHeight", "classView.html#aefd2a49c9f07977af83d5ff3a8e4586f", null ],
    [ "setRequestWidth", "classView.html#a7f83224c343d82872399bbe6e8b45760", null ],
    [ "setRotation", "classView.html#ae72c9399f734d324ec7804dfd4bef405", null ],
    [ "setViewHeight", "classView.html#acbd157d490921f1945d81f198a8f016f", null ],
    [ "setViewLeft", "classView.html#ae2e0eb95cf0a27d004f4bd13ffda80ad", null ],
    [ "setViewTop", "classView.html#a2bc5a28c964210ea39d1eb270c30200c", null ],
    [ "setViewWidth", "classView.html#a3daf26babf3e0502696d1af401b08232", null ],
    [ "viewPortSet", "classView.html#a0eec96d2a3ec25abba83d639737111be", null ],
    [ "allow_upscaling", "classView.html#a89afa2a83e27664ebabe4d835a08fced", null ],
    [ "cmap", "classView.html#aef2cc576c53dc89c1b0e56f898637bb0", null ],
    [ "cmapped", "classView.html#ab8f56e796bef6f4f53a2e4b0b96b27e5", null ],
    [ "colourspace", "classView.html#ae4d962c68d2c740d5b74784420624b5c", null ],
    [ "contrast", "classView.html#a0eb16fb9e47c8a0f120392682280c14a", null ],
    [ "ctw", "classView.html#afa69db05c497c874f872249f6bd24223", null ],
    [ "embed_icc", "classView.html#a00d687587ca91d27fe705fb642e4a611", null ],
    [ "equalization", "classView.html#a5bf5002eeb7a74fb275f4bc628694314", null ],
    [ "flip", "classView.html#a5445431e62f1f4fa2b8e39e5b116dd9f", null ],
    [ "gamma", "classView.html#a66501d855c367e23894d2ca9958d7b44", null ],
    [ "inverted", "classView.html#af40f237efd940ec20457da749f8b464e", null ],
    [ "layers", "classView.html#ac2d157433d47b53439fec339fc6be28e", null ],
    [ "maintain_aspect", "classView.html#a5ac9e196f50d7dff4d4dab53f224d748", null ],
    [ "max_layers", "classView.html#a65d44ca93e3e4712909232ab5961e410", null ],
    [ "output_format", "classView.html#a97559125ceaddb8a589c390934a338c8", null ],
    [ "shade", "classView.html#a6caf330847d42fc8f5527359cade610c", null ],
    [ "shaded", "classView.html#a605b9d2c55831e9daa9d270d17f45c7d", null ],
    [ "xangle", "classView.html#a82a11c648c77bb3a67773fd5449f5bda", null ],
    [ "yangle", "classView.html#a272483c42cab8c6340ccd9aee4a0a590", null ]
];
